.thumb-container[data-v-2fbd9d4d]{position:relative;display:flex;align-items:center;justify-content:center}.play-button-overlay[data-v-2fbd9d4d]{position:absolute;inset:0;display:flex;align-items:center;justify-content:center;pointer-events:none}.play-button-overlay .v-btn[data-v-2fbd9d4d]{pointer-events:all}.v-card[data-v-2fbd9d4d]{background-color:rgb(var(--v-theme-panel));transition:opacity .4s ease-in-out;border-radius:3px;padding:10px}@media(max-width:575px){.v-card[data-v-2fbd9d4d]{padding:6px}.panel-item-details[data-v-2fbd9d4d]{margin-top:6px}}.v-card.unavailable[data-v-2fbd9d4d]{opacity:.3}.panel-item-details[data-v-2fbd9d4d]{padding:0!important;margin-top:10px}.hiresicon[data-v-2fbd9d4d]{margin-left:10px;margin-right:10px}.hiresiconinverted[data-v-2fbd9d4d]{margin-left:10px;margin-right:10px;filter:invert(100%)}.v-list-item-subtitle[data-v-2fbd9d4d]{color:rgb(var(--v-theme-on-panel),.6)!important;font-size:small!important}
