.dsp-pipeline-card[data-v-0e0b8e42]{min-width:160px;transition:all .2s ease}.dsp-pipeline-card[data-v-0e0b8e42]:hover,.filter-selected[data-v-0e0b8e42]{transform:translate(4px)}.add-filter-btn[data-v-0e0b8e42]{background:transparent;border:1px dashed rgba(0,0,0,.5);cursor:pointer}.v-theme--dark .add-filter-btn[data-v-0e0b8e42]{border-color:#ffffff80}.add-filter-btn[data-v-0e0b8e42]:hover{border-color:rgb(var(--v-theme-primary));transform:none}.graph-container[data-v-ac29d681]{position:relative;aspect-ratio:7/2;width:100%;background:var(--v-surface-variant);border-radius:4px;overflow:hidden}.frequency-graph[data-v-ac29d681]{width:100%;height:100%}
